﻿/// <reference path="../API/Agility.js" />
/// <reference path="../API/Agility.UGC.API.js" />


Agility.RegisterNamespace("Modules.SubmitVideo");


(function(SubmitVideo) {

    var BrowseButtonUrl = "";
    var pnlMediaUpload = null;
    var uploadBegin = false;
    var uploadComplete = false;
    var TwitterMessage = "";
    var CurrentVideoSubmission = null;
    var MaxVideoDialog = null;
    var SubmitInProgress = false;

    SubmitVideo.Init = function(browseButton) {
        pnlMediaUpload = $("#UploadArea");

        BrowseButtonUrl = browseButton;

        _setupVideoInputFile();

    };

    SubmitVideo.ConfirmAuthentication = function() {
        if (!Doritos.ContextUtil.IsAuthenticated() || !Doritos.ContextUtil.UserCanSubmitVideo()) {
            location.href = Agility.ResolveUrl("~/Register.aspx");
        }
        else {
            SubmitVideo.VerifyUserVideoCount();

            $("#divSubmitVideo").show();
        }
    }


    function _setupVideoInputFile() {
        debugger;
        var txtVideoFile = $("#txtVideoFile");
        txtVideoFile.val("");
        var inputID = txtVideoFile.attr("id");
        var attachmentPanel = $("div.AttachmentPanel", txtVideoFile.parent().parent());

        var fieldType = { MaxLength: (1000 * 1024) };

        Agility.UGC.API.GetAmazonS3Form({


            fieldName: "Video",
            fieldType: fieldType,
            inputID: inputID,
            fieldPanel: pnlMediaUpload,
            swfUploadUrl: Agility.ResolveUrl("~/Scripts/SwfUpload/swfupload.swf"),
            uploadButtonImageUrl: Agility.ResolveUrl(BrowseButtonUrl),
            uploadButtonImageWidth: 85,
            uploadButtonImageHeight: 22,

            beforeUpload: function(fileName, mime, filesize, uploader) {

                //before upload
                uploadBegin = true;

                var mimeOk = jQuery.inArray(mime, AllowedVideoMimeTypes) >= 0;
                if (!mimeOk) {
                    // Error wrong file type
                    //alert("Error wrong file type");
                    _showError(null, 0);
                    txtVideoFile.val("");
                    if (uploader != undefined && uploader != null) {
                        //Reset the fileName ..
                        uploader.cancelUpload(null, false);
                    }
                    return false;
                }


                var AttachmentProgress = $("#divProgressArea");
                AttachmentProgress.show();

                var AttachmentName = $("#divAttachmentName");
                AttachmentName.html(fileName);


            },

            uploadComplete: function(key, filesize) {

                //upload complete
                uploadComplete = true;
                //hide the progress...

                setTimeout(function() {
                    $("#divProgressArea").hide();
                    $("#ProgressPercentage").html("- " + "Upload Complete");
                }, 50);



                var path = key.split('/');
                txtVideoFile.prev().html("<b>" + path[path.length - 1] +
                    "</b>&nbsp;&nbsp;<a href='javascript:;'>" + txtVideoFile.attr("RemoveLabel") + "</a><br/>");

            },

            uploadError: function(file, errorCode, message) {

                //upload error...
                txtVideoFile.val("");

                uploadComplete = true;
                uploadBegin = false;

                //determine the message...
                switch (errorCode) {
                    case SWFUpload.QUEUE_ERROR.FILE_EXCEEDS_SIZE_LIMIT:
                        //alert("Error:" + "Please choose a file less than or equal to " + fieldType.MaxLength + "kb");
                        _showError(attachmentPanel.parent().next(), 1);
                        break;
                    case SWFUpload.QUEUE_ERROR.ZERO_BYTE_FILE:
                        //alert("Error:" + "Please choose a file greater than zero bytes.");
                        _showError(attachmentPanel.parent().next(), 1);
                        break;
                    case SWFUpload.QUEUE_ERROR.INVALID_FILETYPE:
                    case SWFUpload.UPLOAD_ERROR.FILE_VALIDATION_FAILED:
                        //alert("Error:" + fieldType.ValidationMessage);
                        _showError(attachmentPanel.parent().next(), 0);
                        break;

                    case SWFUpload.UPLOAD_ERROR.HTTP_ERROR:
                    case SWFUpload.UPLOAD_ERROR.IO_ERROR:
                    case SWFUpload.UPLOAD_ERROR.UPLOAD_FAILED:
                    case SWFUpload.UPLOAD_ERROR.UPLOAD_LIMIT_EXCEEDED:
                    case SWFUpload.UPLOAD_ERROR.SPECIFIED_FILE_ID_NOT_FOUND:
                    case SWFUpload.UPLOAD_ERROR.IO_ERROR:
                    case SWFUpload.UPLOAD_ERROR.SECURITY_ERROR:
                        //alert("Error:" + "An error occurred while uploading the file.  Please check your connection and try again.");
                        _showError(attachmentPanel.parent().next(), 2);
                        break;
                    case SWFUpload.UPLOAD_ERROR.FILE_CANCELLED:
                    case SWFUpload.UPLOAD_ERROR.UPLOAD_STOPPED:
                        //ignore these errors...
                        break;
                    default:
                        //alert("Error:" + message + " (code: " + errorCode + ")");
                        _showError(attachmentPanel.parent().next(), 2);
                        break;
                }
            },

            uploadProgress: function(file, bytesLoaded) {
                //progress...

                var percent = Math.ceil((bytesLoaded / file.size) * 100);
                $("#ProgressPercentage").show();
                $("#ProgressPercentage").html(percent + "%");
                $("#divAttachmentProgress").css("width", percent + "%");
            }
        });

    };

    function _showError(panel, no) {
        var errors = $("span.Error", panel).hide();
        if (no != undefined) {
            alert("An Error has occured with the video submission");
            errors.eq(no).show();
        }
    };
    var AllowedVideoMimeTypes = [
            "video/quicktime",  //.mov
            "video/avi",        //.avi
            "video/msvideo",
            "video/x-msvideo",
            "video/mpeg",        //.mpeg
            "video/mp4",
            "video/x-flv",
            "video/3gpp",
            "video/x-matroska",
            "video/x-ms-wmv"
        ];




    SubmitVideo.SubmitVideo = function() {
        var videoFile = $("#txtVideoFile").val();
        var Title = $("#txtVideoTitle").val();


        var record = {
            ID: -1,
            RecordTypeName: "YouTubeVideos",
            Title: Title,
            YouTubeVideo: {
                __type: Agility.UGC.API.FileServiceMetaDataTypeName,
                FileService: Agility.UGC.API.FileService.YouTube,
                OriginalFilePath: videoFile,
                Title: Title,
                Description: Title,
                Category: "Entertainment", //Fixed YouTube category
                Keywords: "Demo",
                Private: true
            }

        };

        Agility.UGC.API.SaveRecord(record, function(data) {
            if (data.ResponseType != 0) {
                alert("There was an error: " + data.Message);
            }
            else {
                alert("Video Successfully Uploaded. A moderator will approve your video shortly.");
                location.href = "./home.php";

            }
        });


    }

})(Modules.SubmitVideo);



