<?php
require_once("$ROOT/model/Record.php");
require_once("$ROOT/model/PagedResults.php");

/**
 * 
 */
class Agility_UGC_API_Basic extends SoapClient
{

  /**
   * 
   * @var array $classmap The defined classes
   * @access private
   */
  private static $classmap = array();
  
  
  public $AuthenticationSettings = null;
  

  /**
   * 
   * @param array $config A array of config values
   * @param string $wsdl The wsdl file to use
   * @access public
   */
  public function __construct($AgilityUGCSettings, array $options = array())
  {
		foreach(self::$classmap as $key => $value)
		{
			if(!isset($options['classmap'][$key]))
			{
				$options['classmap'][$key] = $value;
			}
		}
		
		$this->AuthenticationSettings = $AgilityUGCSettings;
		
		
		$url = $this->AuthenticationSettings->Agility_API_WCF_Url;
		
		$wsdlURL = "$url?wsdl";
		
		parent::__construct($wsdlURL, $options);
   }
   
   
   
   private function GetDataServiceAuthorization(){
		$StartDate  = mktime(0, 0, 0, 1, 1, 2001);
        $Now = time();

        $seconds =floor($Now - $StartDate);
        $profileRecordID = $this->AuthenticationSettings->ProfileRecordID;
        $password = $this->AuthenticationSettings->Agility_API_Password;
        $accessKey = $this->AuthenticationSettings->Agility_API_Key;
        $random = rand(1,1000);
		
		$input = "$seconds.$profileRecordID.$password.$accessKey.$random";
			
		//hash the string using MD5
		$hash = sha1($input);
   
		$auth->AccessHash = $hash;
		$auth->AccessKey = $accessKey;
		$auth->ProfileRecordID = $profileRecordID;
		$auth->RandomNumber = $random;
		$auth->Seconds = $seconds;

		return $auth;
	}
	   
	private function AppendAuthenticationTicket($parameters){
		$params = $parameters;
		$params["auth"] = $this->GetDataServiceAuthorization();
		
		return $params;
	}   
	   

  /**
   * 
   * @param GetRecordType $parameters
   * @access public
   */
  public function GetRecordType($recordTypeID)
  {
	$parameters = array('recordTypeID'=>$recordTypeID);
	
	$authizedParams = $this->AppendAuthenticationTicket($parameters);
    return $this->__soapCall('GetRecordType', array($authizedParams));
  }

  /**
   * 
   * @param GetAllRecordTypes $parameters
   * @access public
   */
  public function GetAllRecordTypes()
  {
	$parameters = array();
	$authizedParams = $this->AppendAuthenticationTicket($parameters);
    return $this->__soapCall('GetAllRecordTypes', array($authizedParams));
  }

  /**
   * 
   * @param DeleteRecordType $parameters
   * @access public
   */
  public function DeleteRecordType($recordTypeID)
  {
	$parameters = array('recordTypeID'=>$recordTypeID);
	 $authizedParams = $this->AppendAuthenticationTicket($parameters);
    return $this->__soapCall('DeleteRecordType', array($authizedParams));
  }

  /**
   * 
   * @param SaveRecordType $parameters
   * @access public
   */
  public function SaveRecordType($parameters)
  {
	$authizedParams = $this->AppendAuthenticationTicket($parameters);
    return $this->__soapCall('SaveRecordType', array($authizedParams));
  }

  /**
   * 
   * @param GetRecord $parameters
   * @access public
   */
  public function GetRecord($recordID)
  {
	$parameters = array('recordID'=>$recordID);
	$authizedParams = $this->AppendAuthenticationTicket($parameters);
	
	$recordResult = $this->__soapCall('GetRecord', array($authizedParams));
	return $recordResult;
	
	
	//$currRecord = new Record($recordResult->GetRecordResult);
    //return $currRecord;
  }

  /**
   * 
   * @param SearchRecords $parameters
   * @access public
   */
  public function SearchRecords($searchArg)
  {
	$parameters = array('searchArg'=>$searchArg);
	$authizedParams = $this->AppendAuthenticationTicket($parameters);
	
	$recordResults = $this->__soapCall('SearchRecords', array($authizedParams));
	$PagedResults = new PagedResults($recordResults->SearchRecordsResult);
	
    return $PagedResults;
  }

  /**
   * 
   * @param SaveRecord $parameters
   * @access public
   */
  public function SaveRecord($Record)
  {
	
		$profileRecordID = $this->AuthenticationSettings->ProfileRecordID;
     
		$url  = $this->AuthenticationSettings->Agility_API_WCF_Url;
		$url  = rtrim($url, "Agility-UGC-API-Basic.svc");
		$url = $url . "SaveRecordHandler.ashx";

		$StartDate  = mktime(0, 0, 0, 1, 1, 2001);
		$Now = time();

		$seconds =floor($Now - $StartDate);
		$profileRecordID = $this->AuthenticationSettings->ProfileRecordID;
		$password = $this->AuthenticationSettings->Agility_API_Password;
		$accessKey = $this->AuthenticationSettings->Agility_API_Key;
		$random = rand(1,1000);
		
		$input = "$seconds.$profileRecordID.$password.$accessKey.$random";
			
		//hash the string using MD5
		$hash = sha1($input);
   
		$url = $url . "?accessKey=" . $accessKey . "&seconds=" . $seconds . "&hash=" . $hash . "&randomNumber=" . $random . "&profileRecordID=" . $profileRecordID;
		
		
		$data = "";
		if ($Record->ID !== null)
		{
			$data = "ID=" . $Record->ID;
		} else {
			$data = "ID=-1";
		}

		$data = $data . "&RecordTypeName=" . urlencode($Record->RecordTypeName);
		 
		foreach ($Record->Values as $key => $value)
		{
			$data = $data . "&" . $key."=" . urlencode($value);		 
		}

		$response =  $this->do_post_request($url, $data);

		//parse the response
		$objDOM = new DOMDocument();
		$xmlParseYN = $objDOM->loadXML($response);		

		if ($xmlParseYN == false) return -1;

		//get the response element
		$responseNodes = $objDOM->getElementsByTagName("recordSaveResponse"); 
		
		if ($responseNodes->length !== 1) {
			throw new Exception("The response from the server could not be interpretted.");
		}

		//check for errors
		$errorNodes = $responseNodes->item(0)->getElementsByTagName("error"); 
		if ($errorNodes->length == 1) {
			throw new Exception($errorNodes->item(0)->textContent);
		}

		//get the id if there were no errors
		$recordIDNodes = $responseNodes->item(0)->getElementsByTagName("recordID"); 
				
		if ($recordIDNodes->length == 1) {		
			return floor($recordIDNodes->item(0)->textContent);
		} 

		return -1;
  }

  /**
   * 
   * @param DeleteRecord $parameters
   * @access public
   */
  public function DeleteRecord($parameters)
  {
	$authizedParams = $this->AppendAuthenticationTicket($parameters);
    return $this->__soapCall('DeleteRecord', array($authizedParams));
  }

  /**
   * 
   * @param SetRecordFlag $parameters
   * @access public
   */
  public function SetRecordFlag($parameters)
  {
	$authizedParams = $this->AppendAuthenticationTicket($parameters);
    return $this->__soapCall('SetRecordFlag', array($authizedParams));
  }

  /**
   * 
   * @param SetRecordState $parameters
   * @access public
   */
  public function SetRecordState($parameters)
  {
	$authizedParams = $this->AppendAuthenticationTicket($parameters);
    return $this->__soapCall('SetRecordState', array($authizedParams));
  }

  /**
   * 
   * @param SetRecordFileState $parameters
   * @access public
   */
  public function SetRecordFileState($parameters)
  {
	$authizedParams = $this->AppendAuthenticationTicket($parameters);
    return $this->__soapCall('SetRecordFileState', array($authizedParams));
  }

  /**
   * 
   * @param GetSettings $parameters
   * @access public
   */
  public function GetSettings($parameters)
  {
	$authizedParams = $this->AppendAuthenticationTicket($parameters);
    return $this->__soapCall('GetSettings', array($authizedParams));
  }

  /**
   * 
   * @param GetAllSystemAccess $parameters
   * @access public
   */
  public function GetAllSystemAccess($parameters)
  {
	$authizedParams = $this->AppendAuthenticationTicket($parameters);
    return $this->__soapCall('GetAllSystemAccess', array($authizedParams));
  }

  /**
   * 
   * @param SaveSettings $parameters
   * @access public
   */
  public function SaveSettings($parameters)
  {
	$authizedParams = $this->AppendAuthenticationTicket($parameters);
    return $this->__soapCall('SaveSettings', array($authizedParams));
  }

  /**
   * 
   * @param DeleteFile $parameters
   * @access public
   */
  public function DeleteFile($parameters)
  {
	$authizedParams = $this->AppendAuthenticationTicket($parameters);
    return $this->__soapCall('DeleteFile', array($authizedParams));
  }

  /**
   * 
   * @param GetUnProcessedFieldValuesForFileService $parameters
   * @access public
   */
  public function GetUnProcessedFieldValuesForFileService($parameters)
  {
	$authizedParams = $this->AppendAuthenticationTicket($parameters);
    return $this->__soapCall('GetUnProcessedFieldValuesForFileService', array($authizedParams));
  }

  /**
   * 
   * @param GetFileMetaData $parameters
   * @access public
   */
  public function GetFileMetaData($parameters)
  {
	$authizedParams = $this->AppendAuthenticationTicket($parameters);
    return $this->__soapCall('GetFileMetaData', array($authizedParams));
  }

  /**
   * 
   * @param GetRecordTypeIDFromRecordID $parameters
   * @access public
   */
  public function GetRecordTypeIDFromRecordID($parameters)
  {
	$authizedParams = $this->AppendAuthenticationTicket($parameters);
    return $this->__soapCall('GetRecordTypeIDFromRecordID', array($authizedParams));
  }

  /**
   * 
   * @param SaveFieldValueFileServiceState $parameters
   * @access public
   */
  public function SaveFieldValueFileServiceState($parameters)
  {
	$authizedParams = $this->AppendAuthenticationTicket($parameters);
    return $this->__soapCall('SaveFieldValueFileServiceState', array($authizedParams));
  }

  /**
   * 
   * @param GetUnProcessedFieldValuesForRecord $parameters
   * @access public
   */
  public function GetUnProcessedFieldValuesForRecord($parameters)
  {
	$authizedParams = $this->AppendAuthenticationTicket($parameters);
    return $this->__soapCall('GetUnProcessedFieldValuesForRecord', array($authizedParams));
  }

  function do_post_request($url, $data, $optional_headers = null)
	{
	  $params = array('http' => array(
				  'method' => 'POST',
				  'content' => $data
				));
	  if ($optional_headers !== null) {
		$params['http']['header'] = $optional_headers;
	  }
	  $ctx = stream_context_create($params);
	  $fp = @fopen($url, 'rb', false, $ctx);
	  if (!$fp) {
		throw new Exception("Problem with $url, $php_errormsg");
	  }
	  $response = @stream_get_contents($fp);
	  if ($response === false) {
		throw new Exception("Problem reading data from $url, $php_errormsg");
	  }
	  return $response;
	}


}
